@@ -33,6 +33,9 @@ class SharePoint(object):
             }
             chrome_options.add_experimental_option("prefs", chrome_prefs)
             driver = webdriver.Chrome(executable_path=chromedriver_location, options=chrome_options)
+            driver.execute_cdp_cmd("Page.addScriptToEvaluateOnNewDocument", {
+                "source": "Object.defineProperty(navigator, 'webdriver', {get: () => undefined})"
+            })
         driver.maximize_window()
         self.static = 5
         self.timeout = 5
@@ -76,6 +79,15 @@ class SharePoint(object):
                  True if "sharedfolder" in _img_types[i].get_attribute("src") else False
                  ) for i, e in enumerate(self.xpaths(d, self.names))]
 
+    def sleep(self, s: int):
+        for i in range(s, -1, -1):
+            time.sleep(1)
+            print("\rthrottled, please wait {}:{}".format(
+                str(i//60).zfill(2),
+                str(i%60).zfill(2)
+            ), end="", flush=True)
+        print(flush=True)
+
     def loop_folder(self, d, location=None, root=False):
         if location is None:
             location = []
@@ -85,14 +97,14 @@ class SharePoint(object):
                 self.scroll_to_bottom_4(d)
                 break
             except:
-                time.sleep(60*5)
+                self.sleep(60*5)
                 d.refresh()
         while True:
             try:
                 current_root_folder = self.get_current_folder(d)
                 break
             except:
-                time.sleep(60*5)
+                self.sleep(60*5)
                 d.refresh()
         if not current_root_folder:
             d.quit()
@@ -102,7 +114,7 @@ class SharePoint(object):
                 folder_items = self.get_folder_items(d)
                 break
             except:
-                time.sleep(60*5)
+                self.sleep(60*5)
                 d.refresh()
         location.append(current_root_folder)
         for i in range(0, len(folder_items)):
@@ -111,21 +123,22 @@ class SharePoint(object):
                     folder_items = self.get_folder_items(d)
                     break
                 except:
-                    time.sleep(60*5)
+                    self.sleep(60*5)
                     d.refresh()
+                    time.sleep(self.static)
+                    self.scroll_to_bottom_4(d)
             current_folder = "\\".join(location)
             if not folder_items[i][4]:
                 current_file = location+[folder_items[i][0]]
                 print(" > ".join(current_file))
                 current_file = "\\".join(current_file)
-                if os.path.isfile(self.save_dir+current_folder+"\\"+current_file):
+                if os.path.isfile(self.save_dir+"\\"+current_file):
                     continue
                 folder_items[i][2].click()
                 folder_items[i][3].click()
                 self.xpath(d, self.dlbtn).click()
                 folder_items[i][2].click()
                 time.sleep(self.static)
-                input()
                 crdownload = [0]
                 while len(crdownload) >= 1:
                     crdownload = [self.save_dir+f for f in os.listdir(self.save_dir) if f.endswith(".crdownload")]
